# -*- cperl -*-
# ABSTRACT: LaTeX document object


use strict;
use warnings;
package SpeL::Object::Document;

use SpeL::Object::ElementList;

use parent 'Exporter';
use Carp;

use Data::Dumper;


sub new {
  my $class = shift;
  my ( $self ) = @_;
  $self = {} unless $self;
  bless $self, $class;
}



1;

__END__

=pod

=encoding UTF-8

=head1 NAME

SpeL::Object::Document - LaTeX document object

=head1 VERSION

version 20240619.1728

=head1 METHODS

=head2 new()

We keep the default method, as the object is generated by the parser.

=head1 SYNOPSYS

Represents a LaTeX document

=head1 AUTHOR

Walter Daems <wdaems@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2024 by Walter Daems.

This is free software, licensed under:

  The GNU General Public License, Version 3, June 2007

=head1 CONTRIBUTOR

=for stopwords Paul Levrie

Paul Levrie

=cut
